==> nextcloud-29.0.10.tgz: nextcloud/apps/updatenotification/l10n/sk.js <==
OC.L10N.register(
    "updatenotification",
    {
    "Channel updated" : "Kanál bol aktualizovaný",
    "Web updater is disabled" : "Aktualizácia cez Web je vypnutá",
    "App updated" : "Aplikácia aktualizovaná",
    "See what's new" : "Pozrite si, čo je nového.",
    "{app} updated to version {version}" : "{app} aktualizovaná na verziu {version}",
    "Update notifications" : "Aktualizovať hlásenia",
    "The update server could not be reached since %d days to check for new updates." : "Aktualizačný server je nedostupný %d dní pre kontrolu aktualizácií.",
    "Please check the Nextcloud and server log files for errors." : "Chyby skontrolujte prosím v logoch Nextcloud a webového servera",
    "Update to {serverAndVersion} is available." : "Je dostupná aktualizácia na {serverAndVersion}.",
    "Update for {app} to version %s is available." : "Pre {app} je dostupná aktualizácia na verziu %s.",
    "Update notification" : "Aktualizovať hlásenie",
    "Displays update notifications for Nextcloud, app updates, and provides the SSO for the updater." : "Zobrazí upozornenie na aktualizáciu pre Nextcloud, aktualizácie aplikácií a poskytuje zjednotené prihlasovanie pre aktualizátor.",
    "What's new in {app} {version}" : "Čo je nové v {app} {version}",
    "Give feedback" : "Poskytnite spätnú väzbu",
    "Get started" : "Začnite!",
    "No changelog available" : "Žiadne zmeny nie sú k dispozícii",
    "Update" : "Aktualizovať",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "Verzia, ktorú používate už nie je podporovaná. Čím skôr aktualizujte na podporovanú verziu prosím.",
    "Apps missing compatible version" : "Aplikácie s chýbajúcou kompatibilnou verziou",
    "View in store" : "Zobraziť v obchode",
    "Apps with compatible version" : "Aplikácie s kompatibilnou verziou",
    "Please note that the web updater is not recommended with more than 100 accounts! Please use the command line updater instead!" : "Upozorňujeme, že aktualizácia cez web sa neodporúča pre viac ako 100 účtov! Namiesto toho použite nástroj na aktualizáciu príkazového riadku!",
    "Open updater" : "Otvoriť aktualizátor",
    "Download now" : "Stiahnuť teraz",
    "Web updater is disabled. Please use the command line updater or the appropriate update mechanism for your installation method (e.g. Docker pull) to update." : "Web updater je zakázaný. Použite prosím príkazový riadok pre aktualizáciu alebo vhodný mechanizmus aktualizácie pre váš inštalačný spôsob (napr. Docker pull) na aktualizáciu.",
    "What's new?" : "Čo je nové?",
    "View changelog" : "Zobraziť súhrn zmien",
    "The update check is not yet finished. Please refresh the page." : "Kontrola aktualizácií ešte neskončila. Obnovte prosím stránku.",
    "Your version is up to date." : "Vaša verzia je aktuálna.",
    "A non-default update server is in use to be checked for updates:" : "Pre kontrolu aktualizácií sa používa iný než predvolený server:",
    "Update channel" : "Aktualizovať kanál",
    "Changing the update channel also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "Zmena aktualizačného kanála ovplyvňuje aj stránku správy aplikácií. Napr. po prepnutí na beta kanál vám budú na stránke správy aplikácií ponúknuté aktualizácie na beta verzie aplikácií.",
    "Current update channel:" : "Aktuálny kanál aktualizácií:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Vždy môžete aktualizovať na novšiu verziu, ale nikdy nemôžete prejsť na nižšiu, stabilnejšiu verziu.",
    "Notify members of the following groups about available updates:" : "Upozorňovať členov nasledujúcich skupín o dostupných aktualizáciach:",
    "No groups" : "Žiadne skupiny",
    "Only notifications for app updates are available." : "Sú dostupné upozornenia iba pre aktualizácie aplikácií.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Pre vybraný aktualizačný kanál budú priradené upozornenia pre server zastarané.",
    "The selected update channel does not support updates of the server." : "Vybraný aktualizačný kanál nepodporuje aktualizácie servera.",
    "A new version is available: <strong>{newVersionString}</strong>" : "Je dostupná nová verzia: <strong>{newVersionString}</strong>",
    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Upozorňujeme, že po oficiálnom vydaní novej verzie môže chvíľu trvať, než sa tu objaví. Nové verzie medzi našich užívateľov distribuujeme priebežne rozložené v čase a ak sa nájdu chyby, niekedy danú verziu preskočíme. Viac informácií o kanáloch aktualizácií a vydaní sa dozviete na {link}",
    "Checked on {lastCheckedDate} - Open changelog" : "Skontrolované dňa {lastCheckedDate} - Otvoriť záznam o zmenách",
    "Checking apps for compatible versions" : "Kontrolujú sa aplikácie na kompatibilné verzie",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Prosím uistite sa, že Váš config.php nemá nastavené <samp>appstoreenabled</samp>na false.",
    "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store." : "Nepodarilo sa pripojiť k obchodu s aplikáciami alebo obchod nemá žiadne aktualizácie. Aktualizácie hľadajte manuálne alebo sa uistite, že Váš server má prístup na internet a že sa môže pripojiť k obchodu.",
    "<strong>All</strong> apps have a compatible version for this Nextcloud version available." : "<strong>Všetky</strong> aplikácie majú dostupnú kompatibilnú verziu s týmto Nextcloudom.",
    "Enterprise" : "Podnikový",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "Pre podnikové použitie. Poskytuje vždy najnovšiu úroveň opráv, ale neaktualizuje sa okamžite na ďalšie hlavné vydanie. K tejto aktualizácii dôjde, keď Nextcloud GmbH urobí ďalšie zodolnenie a testovanie pre veľké a kritické nasadenia. Tento kanál je k dispozícii iba  pre zákazníkov a poskytuje balík Nextcloud Enterprise.",
    "Stable" : "Stabilný",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "Najnovšia stabilná verzia. Je vhodná na bežné používanie a vždy sa aktualizuje na najnovšiu hlavnú verziu.",
    "Beta" : "Beta",
    "A pre-release version only for testing new features, not for production environments." : "Verzia pred vydaním iba na testovanie nových funkcií, nevhodné pre ostrú prevádzku.",
    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available._::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available._" : ["<strong>%n</strong> aplikácia nemá dostupnú kompatibilnú verziu s týmto Nextcloudom","<strong>%n</strong> aplikácie nemajú dostupnú kompatibilnú verziu s týmto Nextcloudom","<strong>%n</strong> aplikácie nemajú dostupnú kompatibilnú verziu s týmto Nextcloudom","<strong>%n</strong> aplikácie nemajú dostupnú kompatibilnú verziu s týmto Nextcloudom"],
    "Changelog for app {app}" : "Zoznam zmien pre aplikáciu {app}",
    "What's new in {app} version {version}" : "Čo je nové v {app} verzie {version}",
    "{version} is available. Get more information on how to update." : "{version} je dostupná. Získajte viac informácií o postupe aktualizácie.",
    "Update to %1$s is available." : "Je dostupná aktualizácia na verziu %1$s.",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Zobrazí upozornenie na aktualizáciu pre Nextcloud a poskytuje zjednotené prihlasovanie pre aktualizátor.",
    "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!" : "Upozorňujeme, že webový aktualizátor sa neodporúča pre viac ako 100 používateľov! Namiesto toho použite nástroj na aktualizáciu príkazového riadku!",
    "Please use the command line updater to update." : "Použite prosím aktualizáciu cez príkazový riadok.",
    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Upozorňujeme, že po oficiálnom vydaní novej verzie môže chvíľu trvať, než sa tu objaví. Nové verzie medzi našich používateľov distribuujeme priebežne rozložené v čase a ak sa nájdu chyby, niekedy danú verziu preskočíme. Viac informácií o kanáloch aktualizácií a vydaní sa dozviete na {link}"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-31.0.13.tgz: nextcloud/apps/updatenotification/l10n/sk.js <==
OC.L10N.register(
    "updatenotification",
    {
    "Channel updated" : "Kanál bol aktualizovaný",
    "Web updater is disabled" : "Aktualizácia cez Web je vypnutá",
    "Configuration is read-only" : "Konfigurácia je iba na čítanie.",
    "App updated" : "Aplikácia aktualizovaná",
    "See what's new" : "Pozrite si, čo je nového.",
    "{app} updated to version {version}" : "{app} aktualizovaná na verziu {version}",
    "Update notifications" : "Aktualizovať hlásenia",
    "The update server could not be reached since %d days to check for new updates." : "Aktualizačný server je nedostupný %d dní pre kontrolu aktualizácií.",
    "Please check the Nextcloud and server log files for errors." : "Chyby skontrolujte prosím v logoch Nextcloud a webového servera",
    "Update to {serverAndVersion} is available." : "Je dostupná aktualizácia na {serverAndVersion}.",
    "Update for {app} to version %s is available." : "Pre {app} je dostupná aktualizácia na verziu %s.",
    "Update notification" : "Aktualizovať hlásenie",
    "Displays update notifications for Nextcloud, app updates, and provides the SSO for the updater." : "Zobrazí upozornenie na aktualizáciu pre Nextcloud, aktualizácie aplikácií a poskytuje zjednotené prihlasovanie pre aktualizátor.",
    "Give feedback" : "Poskytnite spätnú väzbu",
    "Get started" : "Začnite!",
    "No changelog available" : "Žiadne zmeny nie sú k dispozícii",
    "What's new in {app} {version}" : "Čo je nové v {app} {version}",
    "A new version is available: <strong>{newVersionString}</strong>" : "Je dostupná nová verzia: <strong>{newVersionString}</strong>",
    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Upozorňujeme, že po oficiálnom vydaní novej verzie môže chvíľu trvať, než sa tu objaví. Nové verzie medzi našich užívateľov distribuujeme priebežne rozložené v čase a ak sa nájdu chyby, niekedy danú verziu preskočíme. Viac informácií o kanáloch aktualizácií a vydaní sa dozviete na {link}",
    "Checked on {lastCheckedDate} - Open changelog" : "Skontrolované dňa {lastCheckedDate} - Otvoriť záznam o zmenách",
    "Checking apps for compatible versions" : "Kontrolujú sa aplikácie na kompatibilné verzie",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Prosím uistite sa, že Váš config.php nemá nastavené <samp>appstoreenabled</samp>na false.",
    "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store." : "Nepodarilo sa pripojiť k obchodu s aplikáciami alebo obchod nemá žiadne aktualizácie. Aktualizácie hľadajte manuálne alebo sa uistite, že Váš server má prístup na internet a že sa môže pripojiť k obchodu.",
    "<strong>All</strong> apps have a compatible version for this {productName} version available." : "<strong>Všetky</strong> aplikácie majú dostupnú kompatibilnú verziu pre túto verziu {productName}.",
    "Enterprise" : "Podnikový",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately." : "Pre podnikové použitie. Poskytuje vždy najnovšiu úroveň opravy, ale neaktualizuje sa okamžite na ďalšiu hlavnú verziu.",
    "That update happens once {vendor} has done additional hardening and testing for large-scale and mission-critical deployments." : "Aktualizácia prebehne až po tom, čo {vendor} vykoná ďalšie zpevnenie a testovanie pre nasadenia na veľkú škálu a pre kritické misie.",
    "This channel is only available to customers and provides the {enterprise} package." : "Tento kanál je k dispozícii iba pre zákazníkov a poskytuje balík {enterprise}.",
    "Stable" : "Stabilný",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "Najnovšia stabilná verzia. Je vhodná na bežné používanie a vždy sa aktualizuje na najnovšiu hlavnú verziu.",
    "Beta" : "Beta",
    "A pre-release version only for testing new features, not for production environments." : "Verzia pred vydaním iba na testovanie nových funkcií, nevhodné pre ostrú prevádzku.",
    "Update" : "Aktualizovať",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "Verzia, ktorú používate už nie je podporovaná. Čím skôr aktualizujte na podporovanú verziu prosím.",
    "Apps missing compatible version" : "Aplikácie s chýbajúcou kompatibilnou verziou",
    "View in store" : "Zobraziť v obchode",
    "Apps with compatible version" : "Aplikácie s kompatibilnou verziou",
    "Please note that the web updater is not recommended with more than 100 accounts! Please use the command line updater instead!" : "Upozorňujeme, že aktualizácia cez web sa neodporúča pre viac ako 100 účtov! Namiesto toho použite nástroj na aktualizáciu príkazového riadku!",
    "Open updater" : "Otvoriť aktualizátor",
    "Download now" : "Stiahnuť teraz",
    "Web updater is disabled. Please use the command line updater or the appropriate update mechanism for your installation method (e.g. Docker pull) to update." : "Web updater je zakázaný. Použite prosím príkazový riadok pre aktualizáciu alebo vhodný mechanizmus aktualizácie pre váš inštalačný spôsob (napr. Docker pull) na aktualizáciu.",
    "What's new?" : "Čo je nové?",
    "View changelog" : "Zobraziť súhrn zmien",
    "The update check is not yet finished. Please refresh the page." : "Kontrola aktualizácií ešte neskončila. Obnovte prosím stránku.",
    "Your version is up to date." : "Vaša verzia je aktuálna.",
    "A non-default update server is in use to be checked for updates:" : "Pre kontrolu aktualizácií sa používa iný než predvolený server:",
    "Update channel" : "Aktualizovať kanál",
    "Changing the update channel also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "Zmena aktualizačného kanála ovplyvňuje aj stránku správy aplikácií. Napr. po prepnutí na beta kanál vám budú na stránke správy aplikácií ponúknuté aktualizácie na beta verzie aplikácií.",
    "Current update channel:" : "Aktuálny kanál aktualizácií:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Vždy môžete aktualizovať na novšiu verziu, ale nikdy nemôžete prejsť na nižšiu, stabilnejšiu verziu.",
    "Notify members of the following groups about available updates:" : "Upozorňovať členov nasledujúcich skupín o dostupných aktualizáciach:",
    "No groups" : "Žiadne skupiny",
    "Only notifications for app updates are available." : "Sú dostupné upozornenia iba pre aktualizácie aplikácií.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Pre vybraný aktualizačný kanál budú priradené upozornenia pre server zastarané.",
    "The selected update channel does not support updates of the server." : "Vybraný aktualizačný kanál nepodporuje aktualizácie servera.",
    "Changelog for app {app}" : "Zoznam zmien pre aplikáciu {app}",
    "What's new in {app} version {version}" : "Čo je nové v {app} verzie {version}",
    "{version} is available. Get more information on how to update." : "{version} je dostupná. Získajte viac informácií o postupe aktualizácie.",
    "<strong>All</strong> apps have a compatible version for this Nextcloud version available." : "<strong>Všetky</strong> aplikácie majú dostupnú kompatibilnú verziu s týmto Nextcloudom.",
    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available._::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available._" : ["<strong>%n</strong> aplikácia nemá dostupnú kompatibilnú verziu s týmto Nextcloudom","<strong>%n</strong> aplikácie nemajú dostupnú kompatibilnú verziu s týmto Nextcloudom","<strong>%n</strong> aplikácie nemajú dostupnú kompatibilnú verziu s týmto Nextcloudom","<strong>%n</strong> aplikácie nemajú dostupnú kompatibilnú verziu s týmto Nextcloudom"],
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "Pre podnikové použitie. Poskytuje vždy najnovšiu úroveň opráv, ale neaktualizuje sa okamžite na ďalšie hlavné vydanie. K tejto aktualizácii dôjde, keď Nextcloud GmbH urobí ďalšie zodolnenie a testovanie pre veľké a kritické nasadenia. Tento kanál je k dispozícii iba  pre zákazníkov a poskytuje balík Nextcloud Enterprise."
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
